import { computed, defineComponent, openBlock, createElementBlock, unref, resolveComponent, createBlock, resolveDynamicComponent, mergeProps, withCtx, createTextVNode, toDisplayString, createVNode, normalizeClass, Fragment, renderList, createElementVNode, createCommentVNode, normalizeProps, guardReactiveProps, useSlots, toRefs, normalizeStyle, renderSlot } from 'vue';
import katex from 'katex';
import 'katex/dist/katex.min.css';
import Prism from 'prismjs';
import 'prismjs/themes/prism.css';
import { Fragment as Fragment$1 } from 'fragment-for-vue/vue3';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

// utils from react-notion
var getTextContent = function (text) {
    return text.reduce(function (prev, current) { return prev + current[0]; }, "");
};
var groupBlockContent = function (blockMap) {
    var output = [];
    var lastType = undefined;
    var index = -1;
    Object.keys(blockMap).forEach(function (id) {
        var _a;
        (_a = blockMap[id].value.content) === null || _a === void 0 ? void 0 : _a.forEach(function (blockId) {
            var _a, _b;
            var blockType = (_b = (_a = blockMap[blockId]) === null || _a === void 0 ? void 0 : _a.value) === null || _b === void 0 ? void 0 : _b.type;
            if (blockType && blockType !== lastType) {
                index++;
                lastType = blockType;
                output[index] = [];
            }
            output[index].push(blockId);
        });
        lastType = undefined;
    });
    return output;
};
var getListNumber = function (blockId, blockMap) {
    var groups = groupBlockContent(blockMap);
    var group = groups.find(function (g) { return g.includes(blockId); });
    if (!group) {
        return;
    }
    return group.indexOf(blockId) + 1;
};
var defaultMapImageUrl = function (image, block) {
    if (image === void 0) { image = ""; }
    var url = new URL("https://www.notion.so".concat(image.startsWith("/image") ? image : "/image/".concat(encodeURIComponent(image))));
    if (block && !image.includes("/images/page-cover/")) {
        var table = block.value.parent_table === "space" ? "block" : block.value.parent_table;
        url.searchParams.set("table", table);
        url.searchParams.set("id", block.value.id);
        url.searchParams.set("cache", "v2");
    }
    return url.toString();
};
var defaultMapPageUrl = function (pageId) {
    if (pageId === void 0) { pageId = ""; }
    pageId = pageId.replace(/-/g, "");
    return "/".concat(pageId);
};

var defineNotionProps = {
    blockMap: { type: Object, required: true },
    contentId: { type: String, required: false },
    contentIndex: { type: Number, default: 0 },
    embedAllow: { type: String, default: "fullscreen" },
    fullPage: { type: Boolean, default: false },
    hideList: { type: Array, default: function () { return []; } },
    level: { type: Number, default: 0 },
    mapImageUrl: { type: Function, default: defaultMapImageUrl },
    mapPageUrl: { type: Function, default: defaultMapPageUrl },
    pageLinkOptions: Object,
    pageLinkTarget: { type: String, default: "_self" },
    prism: { type: Boolean, default: false },
    katex: { type: Boolean, default: false },
    textLinkTarget: { type: String, default: "_blank" },
    todo: { type: Boolean, default: false },
};
var useNotionBlock = function (props) {
    var block = computed(function () {
        if (!props.blockMap)
            return;
        var id = props.contentId || Object.keys(props.blockMap)[0];
        return props.blockMap[id];
    });
    var pass = computed(function () {
        return {
            blockMap: props.blockMap,
            contentId: props.contentId,
            contentIndex: props.contentIndex,
            embedAllow: props.embedAllow,
            fullPage: props.fullPage,
            hideList: props.hideList,
            level: props.level,
            mapImageUrl: props.mapImageUrl,
            mapPageUrl: props.mapPageUrl,
            pageLinkOptions: props.pageLinkOptions,
            prism: props.prism,
            katex: props.katex,
            todo: props.todo,
        };
    });
    var f = computed(function () {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w;
        return {
            block_aspect_ratio: (_c = (_b = (_a = block.value) === null || _a === void 0 ? void 0 : _a.value) === null || _b === void 0 ? void 0 : _b.format) === null || _c === void 0 ? void 0 : _c.block_aspect_ratio,
            block_height: ((_f = (_e = (_d = block.value) === null || _d === void 0 ? void 0 : _d.value) === null || _e === void 0 ? void 0 : _e.format) === null || _f === void 0 ? void 0 : _f.block_height) || 1,
            block_width: ((_j = (_h = (_g = block.value) === null || _g === void 0 ? void 0 : _g.value) === null || _h === void 0 ? void 0 : _h.format) === null || _j === void 0 ? void 0 : _j.block_width) || 1,
            block_color: (_m = (_l = (_k = block.value) === null || _k === void 0 ? void 0 : _k.value) === null || _l === void 0 ? void 0 : _l.format) === null || _m === void 0 ? void 0 : _m.block_color,
            bookmark_icon: (_q = (_p = (_o = block.value) === null || _o === void 0 ? void 0 : _o.value) === null || _p === void 0 ? void 0 : _p.format) === null || _q === void 0 ? void 0 : _q.bookmark_icon,
            bookmark_cover: (_t = (_s = (_r = block.value) === null || _r === void 0 ? void 0 : _r.value) === null || _s === void 0 ? void 0 : _s.format) === null || _t === void 0 ? void 0 : _t.bookmark_cover,
            display_source: (_w = (_v = (_u = block.value) === null || _u === void 0 ? void 0 : _u.value) === null || _v === void 0 ? void 0 : _v.format) === null || _w === void 0 ? void 0 : _w.display_source,
        };
    });
    var format = computed(function () { var _a; return (_a = block.value) === null || _a === void 0 ? void 0 : _a.value.format; });
    var properties = computed(function () { var _a; return (_a = block.value) === null || _a === void 0 ? void 0 : _a.value.properties; });
    var icon = computed(function () { var _a; return (_a = format.value) === null || _a === void 0 ? void 0 : _a.page_icon; });
    var width = computed(function () { var _a; return (_a = format.value) === null || _a === void 0 ? void 0 : _a.block_width; });
    var title = computed(function () { var _a; return (_a = properties.value) === null || _a === void 0 ? void 0 : _a.title; });
    var caption = computed(function () { var _a; return (_a = properties.value) === null || _a === void 0 ? void 0 : _a.caption; });
    var description = computed(function () { var _a; return (_a = properties.value) === null || _a === void 0 ? void 0 : _a.description; });
    var type = computed(function () {
        var _a;
        return (_a = block.value) === null || _a === void 0 ? void 0 : _a.value.type;
    });
    var visible = computed(function () {
        return !props.hideList.includes(type.value);
    });
    var hasPageLinkOptions = computed(function () {
        var _a, _b;
        return ((_a = props.pageLinkOptions) === null || _a === void 0 ? void 0 : _a.component) && ((_b = props.pageLinkOptions) === null || _b === void 0 ? void 0 : _b.href);
    });
    var parent = computed(function () {
        var _a;
        return props.blockMap[(_a = block.value) === null || _a === void 0 ? void 0 : _a.value.parent_id];
    });
    var isType = function (t) {
        if (Array.isArray(t)) {
            return visible.value && t.includes(type.value);
        }
        return visible.value && type.value === t;
    };
    var blockColorClass = function (suffix) {
        var _a, _b, _c;
        if (suffix === void 0) { suffix = ""; }
        var blockColor = (_c = (_b = (_a = block.value) === null || _a === void 0 ? void 0 : _a.value) === null || _b === void 0 ? void 0 : _b.format) === null || _c === void 0 ? void 0 : _c.block_color;
        return blockColor ? "notion-".concat(blockColor).concat(suffix) : undefined;
    };
    var pageLinkProps = function (id) {
        var _a;
        return _a = {},
            _a[props.pageLinkOptions.href] = props.mapPageUrl(id),
            _a;
    };
    return {
        props: props,
        block: block,
        pass: pass,
        f: f,
        format: format,
        properties: properties,
        icon: icon,
        width: width,
        title: title,
        caption: caption,
        description: description,
        type: type,
        visible: visible,
        hasPageLinkOptions: hasPageLinkOptions,
        parent: parent,
        isType: isType,
        blockColorClass: blockColorClass,
        pageLinkProps: pageLinkProps,
    };
};

var _hoisted_1$k = ["innerHTML"];
var __default__$l = {
    name: "Katex",
};
var script$o = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$l), { props: {
        expression: {
            type: String,
            required: true,
        },
    }, setup: function (__props) {
        var props = __props;
        var html = computed(function () { return katex.renderToString(props.expression); });
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock("span", { innerHTML: unref(html) }, null, 8 /* PROPS */, _hoisted_1$k));
        };
    } }));

script$o.__file = "src/blocks/helpers/katex.vue";

var _hoisted_1$j = ["target", "href"];
var _hoisted_2$c = ["target", "href"];
var _hoisted_3$6 = ["target", "href"];
var _hoisted_4$4 = { key: 5 };
var _hoisted_5$2 = {
    key: 7,
    class: "notion-inline-code"
};
var _hoisted_6$2 = { key: 8 };
var _hoisted_7$2 = { key: 9 };
var _hoisted_8$2 = { key: 10 };
var _hoisted_9$1 = {
    key: 12,
    class: "notion-inline-code"
};
var __default__$k = {
    name: "NotionDecorator",
};
var script$n = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$k), { props: __assign({ content: Object }, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), blockProps = _a.props, pass = _a.pass, type = _a.type, hasPageLinkOptions = _a.hasPageLinkOptions, pageLinkProps = _a.pageLinkProps;
        var text = computed(function () { var _a; return (_a = props.content) === null || _a === void 0 ? void 0 : _a[0]; });
        var decorators = computed(function () { var _a; return ((_a = props.content) === null || _a === void 0 ? void 0 : _a[1]) || []; });
        var decoratorKey = computed(function () { var _a, _b; return (_b = (_a = decorators.value) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b[0]; });
        var decoratorValue = computed(function () { var _a, _b; return (_b = (_a = decorators.value) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b[1]; });
        var unappliedDecorators = computed(function () {
            var clonedDecorators = JSON.parse(JSON.stringify(decorators.value || []));
            clonedDecorators.shift(); // remove applied decorator
            return clonedDecorators;
        });
        var nextContent = computed(function () { return [text.value, unappliedDecorators.value]; });
        var isPageLink = computed(function () { return text.value === "‣"; });
        var isInlinePageLink = computed(function () { var _a; return ((_a = decoratorValue.value) === null || _a === void 0 ? void 0 : _a[0]) === "/"; });
        var pageLinkTitle = computed(function () { var _a, _b, _c, _d, _e, _f; return ((_f = (_e = (_d = (_c = (_b = (_a = blockProps.blockMap) === null || _a === void 0 ? void 0 : _a[decoratorValue.value]) === null || _b === void 0 ? void 0 : _b.value) === null || _c === void 0 ? void 0 : _c.properties) === null || _d === void 0 ? void 0 : _d.title) === null || _e === void 0 ? void 0 : _e[0]) === null || _f === void 0 ? void 0 : _f[0]) || "link"; });
        var target = computed(function () {
            if (type.value === "page") {
                return blockProps.pageLinkTarget;
            }
            return blockProps.textLinkTarget;
        });
        return function (_ctx, _cache) {
            var _a, _b;
            var _component_NotionDecorator = resolveComponent("NotionDecorator");
            return (unref(isPageLink) && unref(hasPageLinkOptions))
                ? (openBlock(), createBlock(resolveDynamicComponent((_a = unref(blockProps).pageLinkOptions) === null || _a === void 0 ? void 0 : _a.component), mergeProps({
                    key: 0,
                    class: "notion-link"
                }, unref(pageLinkProps)(unref(decoratorValue))), {
                    default: withCtx(function () { return [
                        createTextVNode(toDisplayString(unref(pageLinkTitle)), 1 /* TEXT */)
                    ]; }),
                    _: 1 /* STABLE */
                }, 16 /* FULL_PROPS */))
                : (unref(isPageLink))
                    ? (openBlock(), createElementBlock("a", {
                        key: 1,
                        class: "notion-link",
                        target: unref(blockProps).pageLinkTarget,
                        href: unref(blockProps).mapPageUrl(unref(decoratorValue))
                    }, toDisplayString(unref(pageLinkTitle)), 9 /* TEXT, PROPS */, _hoisted_1$j))
                    : (unref(decoratorKey) === 'a' && unref(hasPageLinkOptions) && unref(isInlinePageLink))
                        ? (openBlock(), createBlock(resolveDynamicComponent((_b = unref(blockProps).pageLinkOptions) === null || _b === void 0 ? void 0 : _b.component), mergeProps({
                            key: 2,
                            class: "notion-link"
                        }, unref(pageLinkProps)(unref(decoratorValue).slice(1))), {
                            default: withCtx(function () { return [
                                createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                            ]; }),
                            _: 1 /* STABLE */
                        }, 16 /* FULL_PROPS */))
                        : (unref(decoratorKey) === 'a' && unref(isInlinePageLink))
                            ? (openBlock(), createElementBlock("a", {
                                key: 3,
                                class: "notion-link",
                                target: unref(target),
                                href: unref(blockProps).mapPageUrl(unref(decoratorValue).slice(1))
                            }, [
                                createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                            ], 8 /* PROPS */, _hoisted_2$c))
                            : (unref(decoratorKey) === 'a')
                                ? (openBlock(), createElementBlock("a", {
                                    key: 4,
                                    class: "notion-link",
                                    target: unref(target),
                                    href: unref(decoratorValue)
                                }, [
                                    createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                ], 8 /* PROPS */, _hoisted_3$6))
                                : (unref(decorators).length === 0)
                                    ? (openBlock(), createElementBlock("span", _hoisted_4$4, toDisplayString(unref(text)), 1 /* TEXT */))
                                    : (unref(decoratorKey) === 'h')
                                        ? (openBlock(), createElementBlock("span", {
                                            key: 6,
                                            class: normalizeClass('notion-' + unref(decoratorValue))
                                        }, [
                                            createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                        ], 2 /* CLASS */))
                                        : (unref(decoratorKey) === 'c')
                                            ? (openBlock(), createElementBlock("code", _hoisted_5$2, [
                                                createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                            ]))
                                            : (unref(decoratorKey) === 'b')
                                                ? (openBlock(), createElementBlock("b", _hoisted_6$2, [
                                                    createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                ]))
                                                : (unref(decoratorKey) === 'i')
                                                    ? (openBlock(), createElementBlock("em", _hoisted_7$2, [
                                                        createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                    ]))
                                                    : (unref(decoratorKey) === 's')
                                                        ? (openBlock(), createElementBlock("s", _hoisted_8$2, [
                                                            createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                        ]))
                                                        : (unref(decoratorKey) === 'e' && unref(blockProps).katex)
                                                            ? (openBlock(), createBlock(script$o, {
                                                                key: 11,
                                                                expression: unref(decoratorValue)
                                                            }, null, 8 /* PROPS */, ["expression"]))
                                                            : (unref(decoratorKey) === 'e')
                                                                ? (openBlock(), createElementBlock("code", _hoisted_9$1, toDisplayString(unref(decoratorValue)), 1 /* TEXT */))
                                                                : (openBlock(), createBlock(_component_NotionDecorator, mergeProps({
                                                                    key: 13,
                                                                    content: unref(nextContent)
                                                                }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"]));
        };
    } }));

script$n.__file = "src/blocks/decorator.vue";

var __default__$j = {
    name: "NotionTextRenderer",
};
var script$m = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$j), { props: __assign({ text: Array }, defineNotionProps), setup: function (__props) {
        var props = __props;
        var pass = useNotionBlock(props).pass;
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock("span", null, [
                (openBlock(true), createElementBlock(Fragment, null, renderList(__props.text, function (t, i) {
                    return (openBlock(), createBlock(script$n, mergeProps({
                        key: i,
                        content: t
                    }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"]));
                }), 128 /* KEYED_FRAGMENT */))
            ]));
        };
    } }));

script$m.__file = "src/blocks/helpers/text-renderer.vue";

var _hoisted_1$i = { class: "notion-row" };
var _hoisted_2$b = ["href"];
var _hoisted_3$5 = { class: "notion-bookmark-title" };
var _hoisted_4$3 = {
    key: 0,
    class: "notion-bookmark-description"
};
var _hoisted_5$1 = { class: "notion-bookmark-link" };
var _hoisted_6$1 = ["alt", "src"];
var _hoisted_7$1 = {
    key: 0,
    class: "notion-bookmark-image"
};
var _hoisted_8$1 = ["alt", "src"];
var __default__$i = {
    name: "NotionBookmark",
};
var script$l = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$i), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), f = _a.f, properties = _a.properties, title = _a.title, description = _a.description, pass = _a.pass;
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock("div", _hoisted_1$i, [
                createElementVNode("a", {
                    target: "_blank",
                    rel: "noopener noreferrer",
                    class: normalizeClass(['notion-bookmark', unref(f).block_color && "notion-".concat(unref(f).block_color)]),
                    href: unref(properties).link
                }, [
                    createElementVNode("div", null, [
                        createElementVNode("div", _hoisted_3$5, [
                            createVNode(script$m, mergeProps({
                                text: unref(title) || unref(properties).link
                            }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        (unref(description))
                            ? (openBlock(), createElementBlock("div", _hoisted_4$3, [
                                createVNode(script$m, mergeProps({ text: unref(description) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ]))
                            : createCommentVNode("v-if", true),
                        createElementVNode("div", _hoisted_5$1, [
                            (unref(f).bookmark_icon)
                                ? (openBlock(), createElementBlock("img", {
                                    key: 0,
                                    alt: unref(getTextContent)(unref(title) || unref(properties).link),
                                    src: unref(f).bookmark_icon
                                }, null, 8 /* PROPS */, _hoisted_6$1))
                                : createCommentVNode("v-if", true),
                            createElementVNode("div", null, [
                                createVNode(script$m, mergeProps({
                                    text: unref(properties).link
                                }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ])
                        ])
                    ]),
                    (unref(f).bookmark_cover)
                        ? (openBlock(), createElementBlock("div", _hoisted_7$1, [
                            createElementVNode("img", {
                                alt: unref(getTextContent)(unref(title) || unref(properties).link),
                                src: unref(f).bookmark_cover
                            }, null, 8 /* PROPS */, _hoisted_8$1)
                        ]))
                        : createCommentVNode("v-if", true)
                ], 10 /* CLASS, PROPS */, _hoisted_2$b)
            ]));
        };
    } }));

script$l.__file = "src/blocks/bookmark.vue";

var _hoisted_1$h = ["src", "alt"];
var _hoisted_2$a = ["aria-label"];
var __default__$h = {
    name: "NotionPageIcon",
};
var script$k = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$h), { props: __assign({ big: Boolean }, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), icon = _a.icon, format = _a.format, block = _a.block, title = _a.title;
        return function (_ctx, _cache) {
            var _a;
            return ((_a = unref(icon)) === null || _a === void 0 ? void 0 : _a.includes('http'))
                ? (openBlock(), createElementBlock("img", {
                    key: 0,
                    class: normalizeClass([unref(format).page_cover && 'notion-page-icon-offset', __props.big ? 'notion-page-icon-cover' : 'notion-page-icon']),
                    src: props.mapImageUrl(unref(icon), unref(block)),
                    alt: unref(title) ? unref(getTextContent)(unref(title)) : 'Icon'
                }, null, 10 /* CLASS, PROPS */, _hoisted_1$h))
                : (unref(icon))
                    ? (openBlock(), createElementBlock("span", {
                        key: 1,
                        role: "img",
                        "aria-label": unref(icon),
                        class: normalizeClass([
                            'notion-emoji',
                            unref(format).page_cover && 'notion-page-icon-offset',
                            __props.big ? 'notion-page-icon-cover' : 'notion-page-icon',
                        ])
                    }, toDisplayString(unref(icon)), 11 /* TEXT, CLASS, PROPS */, _hoisted_2$a))
                    : createCommentVNode("v-if", true);
        };
    } }));

script$k.__file = "src/blocks/helpers/page-icon.vue";

var _hoisted_1$g = { style: { "font-size": "12px" } };
var _hoisted_2$9 = { class: "notion-callout-text" };
var __default__$g = {
    name: "NotionCallout",
};
var script$j = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$g), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), pass = _a.pass, title = _a.title, blockColorClass = _a.blockColorClass;
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock("div", {
                class: normalizeClass(['notion-callout', unref(blockColorClass)()])
            }, [
                createElementVNode("div", _hoisted_1$g, [
                    createVNode(script$k, normalizeProps(guardReactiveProps(unref(pass))), null, 16 /* FULL_PROPS */)
                ]),
                createElementVNode("div", _hoisted_2$9, [
                    createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ])
            ], 2 /* CLASS */));
        };
    } }));

script$j.__file = "src/blocks/callout.vue";

var _hoisted_1$f = ["innerHTML"];
var _hoisted_2$8 = /*#__PURE__*/ createTextVNode("    ");
var _hoisted_3$4 = ["innerHTML"];
var _hoisted_4$2 = /*#__PURE__*/ createTextVNode("\r\n  ");
var script$i = /*#__PURE__*/ defineComponent({
    props: {
        code: {
            type: String,
        },
        inline: {
            type: Boolean,
            default: false,
        },
        language: {
            type: String,
            default: "markup",
        },
    },
    setup: function (__props) {
        var _a;
        var props = __props;
        var slots = useSlots();
        var _b = toRefs(props), inline = _b.inline, language = _b.language;
        var className = computed(function () { return "language-".concat(language.value); });
        var defaultSlot = (slots && slots.default && slots.default()) || [];
        var code = props.code || (defaultSlot && defaultSlot.length && ((_a = defaultSlot[0]) === null || _a === void 0 ? void 0 : _a.children)) ? defaultSlot[0].children : "";
        var d = computed(function () { return Prism === null || Prism === void 0 ? void 0 : Prism.highlight(code, Prism === null || Prism === void 0 ? void 0 : Prism.languages[language.value], "en"); });
        return function (_ctx, _cache) {
            return (unref(inline))
                ? (openBlock(), createElementBlock("code", {
                    key: 0,
                    class: normalizeClass(unref(className)),
                    innerHTML: unref(d)
                }, null, 10 /* CLASS, PROPS */, _hoisted_1$f))
                : (openBlock(), createElementBlock("pre", {
                    key: 1,
                    class: normalizeClass(unref(className))
                }, [
                    _hoisted_2$8,
                    createElementVNode("code", { innerHTML: unref(d) }, null, 8 /* PROPS */, _hoisted_3$4),
                    _hoisted_4$2
                ], 2 /* CLASS */));
        };
    }
});

script$i.__file = "src/blocks/helpers/prism.vue";

var __default__$f = {
    name: "NotionCode",
};
var script$h = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$f), { props: __assign({ overrideLang: String, overrideLangClass: String }, defineNotionProps), setup: function (__props) {
        var props = __props;
        var properties = useNotionBlock(props).properties;
        var lang = computed(function () {
            var _a, _b, _c, _d;
            return props.overrideLang || ((_d = (_c = (_b = (_a = properties.value) === null || _a === void 0 ? void 0 : _a.language) === null || _b === void 0 ? void 0 : _b[0]) === null || _c === void 0 ? void 0 : _c[0]) === null || _d === void 0 ? void 0 : _d.toLowerCase());
        });
        var langClass = computed(function () {
            return props.overrideLangClass || "language-".concat(lang.value);
        });
        var supported = computed(function () {
            return Prism === null || Prism === void 0 ? void 0 : Prism.languages[lang.value];
        });
        return function (_ctx, _cache) {
            var _a;
            return (unref(supported))
                ? (openBlock(), createElementBlock("pre", {
                    key: 0,
                    class: normalizeClass(['notion-code', unref(langClass)])
                }, [
                    createVNode(script$i, { language: unref(lang) }, {
                        default: withCtx(function () {
                            var _a;
                            return [
                                createTextVNode(toDisplayString((_a = unref(properties)) === null || _a === void 0 ? void 0 : _a.title[0][0]), 1 /* TEXT */)
                            ];
                        }),
                        _: 1 /* STABLE */
                    }, 8 /* PROPS */, ["language"])
                ], 2 /* CLASS */))
                : (openBlock(), createElementBlock("pre", {
                    key: 1,
                    class: normalizeClass(['notion-code', unref(langClass)])
                }, [
                    createElementVNode("code", {
                        class: normalizeClass(unref(langClass))
                    }, toDisplayString((_a = unref(properties)) === null || _a === void 0 ? void 0 : _a.title[0][0]), 3 /* TEXT, CLASS */)
                ], 2 /* CLASS */));
        };
    } }));

script$h.__file = "src/blocks/code.vue";

var __default__$e = {
    name: "NotionColumn",
};
var script$g = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$e), { props: {
        format: { type: Object, required: true },
    }, setup: function (__props) {
        var props = __props;
        var baseWidth = 46; // todo: add magic numbers to a config json
        var columnStyle = computed(function () {
            var columns = Number((1 / props.format.column_ratio).toFixed(0));
            var totalWidth = (columns - 1) * baseWidth;
            return {
                width: "calc((100% - ".concat(totalWidth, "px) * ").concat(props.format.column_ratio, ")"),
            };
        });
        var spacerStyle = computed(function () { return ({ width: "".concat(baseWidth, "px") }); });
        return function (_ctx, _cache) {
            return (openBlock(), createBlock(unref(Fragment$1), null, {
                default: withCtx(function () { return [
                    createElementVNode("div", {
                        class: "notion-column",
                        style: normalizeStyle(unref(columnStyle))
                    }, [
                        renderSlot(_ctx.$slots, "default")
                    ], 4 /* STYLE */),
                    createElementVNode("div", {
                        class: "notion-spacer",
                        style: normalizeStyle(unref(spacerStyle))
                    }, null, 4 /* STYLE */)
                ]; }),
                _: 3 /* FORWARDED */
            }));
        };
    } }));

script$g.__file = "src/blocks/column.vue";

var _hoisted_1$e = { key: 0 };
var __default__$d = {
    name: "NotionEquation",
};
var script$f = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$d), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), properties = _a.properties, pass = _a.pass;
        var equation = computed(function () { var _a, _b; return (_b = (_a = properties.value.title) === null || _a === void 0 ? void 0 : _a[0]) === null || _b === void 0 ? void 0 : _b[0]; });
        return function (_ctx, _cache) {
            return (props.katex)
                ? (openBlock(), createElementBlock("div", _hoisted_1$e, [
                    createVNode(script$o, { expression: unref(equation) }, null, 8 /* PROPS */, ["expression"])
                ]))
                : (openBlock(), createBlock(script$h, mergeProps({ key: 1 }, unref(pass), {
                    overrideLang: "latex",
                    overrideLangClass: "language-latex"
                }), null, 16 /* FULL_PROPS */));
        };
    } }));

script$f.__file = "src/blocks/equation.vue";

var _hoisted_1$d = ["src", "allow"];
var __default__$c = {
    name: "NotionAsset",
};
var script$e = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$c), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), type = _a.type, properties = _a.properties, f = _a.f;
        var src = computed(function () {
            var _a;
            return type.value === "figma" ? (_a = properties.value) === null || _a === void 0 ? void 0 : _a.source[0][0] : f.value.display_source;
        });
        var style = computed(function () {
            var aspectRatio = f.value.block_aspect_ratio || f.value.block_height / f.value.block_width;
            return {
                paddingBottom: "".concat(aspectRatio * 100, "%"),
                position: "relative",
            };
        });
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock("div", {
                style: normalizeStyle(unref(style))
            }, [
                createElementVNode("iframe", {
                    class: "notion-image-inset",
                    style: { "width": "100%" },
                    src: unref(src),
                    allow: props.embedAllow
                }, null, 8 /* PROPS */, _hoisted_1$d)
            ], 4 /* STYLE */));
        };
    } }));

script$e.__file = "src/blocks/helpers/asset.vue";

var _hoisted_1$c = ["alt", "src"];
var _hoisted_2$7 = ["alt", "src"];
var __default__$b = {
    name: "NotionImage",
};
var script$d = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$b), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), caption = _a.caption, properties = _a.properties, block = _a.block, f = _a.f;
        var alt = computed(function () {
            var _a;
            return (_a = caption === null || caption === void 0 ? void 0 : caption.value) === null || _a === void 0 ? void 0 : _a[0][0];
        });
        var src = computed(function () {
            var _a;
            return props.mapImageUrl((_a = properties.value) === null || _a === void 0 ? void 0 : _a.source[0][0], block.value);
        });
        var style = computed(function () {
            var aspectRatio = f.value.block_aspect_ratio || f.value.block_height / f.value.block_width;
            return {
                paddingBottom: "".concat(aspectRatio * 100, "%"),
                position: "relative",
            };
        });
        return function (_ctx, _cache) {
            return (unref(f).block_aspect_ratio)
                ? (openBlock(), createElementBlock("div", {
                    key: 0,
                    style: normalizeStyle(unref(style))
                }, [
                    createElementVNode("img", {
                        class: "notion-image-inset",
                        alt: unref(alt) || 'Notion image',
                        src: unref(src)
                    }, null, 8 /* PROPS */, _hoisted_1$c)
                ], 4 /* STYLE */))
                : (openBlock(), createElementBlock("img", {
                    key: 1,
                    alt: unref(caption),
                    src: unref(src)
                }, null, 8 /* PROPS */, _hoisted_2$7));
        };
    } }));

script$d.__file = "src/blocks/helpers/image.vue";

var _hoisted_1$b = {
    key: 2,
    class: "notion-image-caption"
};
var __default__$a = {
    name: "NotionFigure",
};
var script$c = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$a), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), pass = _a.pass, width = _a.width, caption = _a.caption, isType = _a.isType;
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock("figure", {
                class: "notion-asset-wrapper",
                style: normalizeStyle(unref(width))
            }, [
                (unref(isType)('image'))
                    ? (openBlock(), createBlock(script$d, normalizeProps(mergeProps({ key: 0 }, unref(pass))), null, 16 /* FULL_PROPS */))
                    : (unref(isType)(['embed', 'video', 'figma']))
                        ? (openBlock(), createBlock(script$e, normalizeProps(mergeProps({ key: 1 }, unref(pass))), null, 16 /* FULL_PROPS */))
                        : createCommentVNode("v-if", true),
                (unref(caption))
                    ? (openBlock(), createElementBlock("figcaption", _hoisted_1$b, [
                        createVNode(script$m, mergeProps({ text: unref(caption) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                    ]))
                    : createCommentVNode("v-if", true)
            ], 4 /* STYLE */));
        };
    } }));

script$c.__file = "src/blocks/helpers/figure.vue";

var _hoisted_1$a = {
    key: 0,
    class: "notion-h1"
};
var _hoisted_2$6 = {
    key: 1,
    class: "notion-h2"
};
var _hoisted_3$3 = {
    key: 2,
    class: "notion-h3"
};
var __default__$9 = {
    name: "NotionHeader",
};
var script$b = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$9), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), type = _a.type, title = _a.title, pass = _a.pass;
        return function (_ctx, _cache) {
            return (unref(type) === 'header')
                ? (openBlock(), createElementBlock("h1", _hoisted_1$a, [
                    createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ]))
                : (unref(type) === 'sub_header')
                    ? (openBlock(), createElementBlock("h2", _hoisted_2$6, [
                        createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                    ]))
                    : (unref(type) === 'sub_sub_header')
                        ? (openBlock(), createElementBlock("h3", _hoisted_3$3, [
                            createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]))
                        : createCommentVNode("v-if", true);
        };
    } }));

script$b.__file = "src/blocks/header.vue";

var _hoisted_1$9 = {
    key: 0,
    class: "notion-list notion-list-disc"
};
var _hoisted_2$5 = {
    key: 1,
    class: "notion-list notion-list-numbered"
};
var __default__$8 = {
    name: "NotionNestedList",
};
var script$a = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$8), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), block = _a.block, type = _a.type;
        computed(function () { return getListNumber(block.value.value.id, props.blockMap); });
        return function (_ctx, _cache) {
            return (unref(type) === 'bulleted_list')
                ? (openBlock(), createElementBlock("ul", _hoisted_1$9, [
                    renderSlot(_ctx.$slots, "default")
                ]))
                : (openBlock(), createElementBlock("ol", _hoisted_2$5, [
                    renderSlot(_ctx.$slots, "default")
                ]));
        };
    } }));

script$a.__file = "src/blocks/helpers/nested-list.vue";

var _hoisted_1$8 = {
    key: 0,
    class: "notion-list notion-list-disc"
};
var _hoisted_2$4 = ["start"];
var _hoisted_3$2 = { key: 2 };
var __default__$7 = {
    name: "NotionList",
};
var script$9 = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$7), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), block = _a.block, type = _a.type, title = _a.title, pass = _a.pass;
        var start = computed(function () {
            getListNumber(block.value.value.id, props.blockMap);
        });
        var isTopLevel = computed(function () { return type.value != props.blockMap[block.value.value.parent_id].value.type; });
        return function (_ctx, _cache) {
            return (unref(isTopLevel) && unref(type) === 'bulleted_list')
                ? (openBlock(), createElementBlock("ul", _hoisted_1$8, [
                    createElementVNode("li", null, [
                        createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                    ]),
                    (unref(block).value.content)
                        ? (openBlock(), createBlock(script$a, normalizeProps(mergeProps({ key: 0 }, unref(pass))), {
                            default: withCtx(function () { return [
                                renderSlot(_ctx.$slots, "default")
                            ]; }),
                            _: 3 /* FORWARDED */
                        }, 16 /* FULL_PROPS */))
                        : createCommentVNode("v-if", true)
                ]))
                : (unref(isTopLevel) && unref(type) === 'numbered_list')
                    ? (openBlock(), createElementBlock("ol", {
                        key: 1,
                        class: "notion-list notion-list-numbered",
                        start: unref(start)
                    }, [
                        createElementVNode("li", null, [
                            createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        (unref(block).value.content)
                            ? (openBlock(), createBlock(script$a, normalizeProps(mergeProps({ key: 0 }, unref(pass))), {
                                default: withCtx(function () { return [
                                    renderSlot(_ctx.$slots, "default")
                                ]; }),
                                _: 3 /* FORWARDED */
                            }, 16 /* FULL_PROPS */))
                            : createCommentVNode("v-if", true)
                    ], 8 /* PROPS */, _hoisted_2$4))
                    : (openBlock(), createElementBlock("span", _hoisted_3$2, [
                        createElementVNode("li", null, [
                            createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        (unref(block).value.content)
                            ? (openBlock(), createBlock(script$a, normalizeProps(mergeProps({ key: 0 }, unref(pass))), {
                                default: withCtx(function () { return [
                                    renderSlot(_ctx.$slots, "default")
                                ]; }),
                                _: 3 /* FORWARDED */
                            }, 16 /* FULL_PROPS */))
                            : createCommentVNode("v-if", true)
                    ]));
        };
    } }));

script$9.__file = "src/blocks/list.vue";

var _hoisted_1$7 = {
    key: 0,
    class: "notion"
};
var _hoisted_2$3 = ["alt", "src"];
var _hoisted_3$1 = { class: "notion-title" };
var _hoisted_4$1 = {
    key: 1,
    class: "notion"
};
var _hoisted_5 = { class: "notion-page-icon" };
var _hoisted_6 = { class: "notion-page-text" };
var _hoisted_7 = ["target", "href"];
var _hoisted_8 = { class: "notion-page-icon" };
var _hoisted_9 = { class: "notion-page-text" };
var __default__$6 = {
    name: "NotionPage",
};
var script$8 = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$6), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), format = _a.format, title = _a.title, block = _a.block, pass = _a.pass, hasPageLinkOptions = _a.hasPageLinkOptions, pageLinkProps = _a.pageLinkProps;
        var coverStyle = computed(function () {
            var coverPosition = (1 - (format.value.page_cover_position || 0.5)) * 100;
            return { objectPosition: "center ".concat(coverPosition, "%") };
        });
        return function (_ctx, _cache) {
            var _a;
            return (props.level === 0 && props.fullPage)
                ? (openBlock(), createElementBlock("div", _hoisted_1$7, [
                    createCommentVNode(" todo: add header "),
                    createCommentVNode(" <NotionPageHeader v-if=\"!hideHeader\" v-bind=\"pass\" /> "),
                    createCommentVNode(" todo: hide image if no .format is available "),
                    (unref(format) && unref(format).page_cover)
                        ? (openBlock(), createElementBlock("img", {
                            key: 0,
                            class: "notion-page-cover",
                            style: normalizeStyle(unref(coverStyle)),
                            alt: unref(getTextContent)(unref(title)),
                            src: props.mapImageUrl(unref(format).page_cover, unref(block))
                        }, null, 12 /* STYLE, PROPS */, _hoisted_2$3))
                        : createCommentVNode("v-if", true),
                    createElementVNode("main", {
                        class: normalizeClass([
                            'notion-page',
                            unref(format) && !unref(format).page_cover && 'notion-page-offset',
                            unref(format) && unref(format).page_full_width && 'notion-full-width',
                            unref(format) && unref(format).page_small_text && 'notion-small-text',
                        ])
                    }, [
                        createVNode(script$k, mergeProps(unref(pass), { big: "" }), null, 16 /* FULL_PROPS */),
                        createElementVNode("div", _hoisted_3$1, [
                            createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        renderSlot(_ctx.$slots, "default")
                    ], 2 /* CLASS */)
                ]))
                : (props.level === 0)
                    ? (openBlock(), createElementBlock("main", _hoisted_4$1, [
                        renderSlot(_ctx.$slots, "default")
                    ]))
                    : (unref(hasPageLinkOptions))
                        ? (openBlock(), createBlock(resolveDynamicComponent((_a = props.pageLinkOptions) === null || _a === void 0 ? void 0 : _a.component), mergeProps({
                            key: 2,
                            class: "notion-page-link"
                        }, unref(pageLinkProps)(unref(block).value.id)), {
                            default: withCtx(function () { return [
                                createElementVNode("div", _hoisted_5, [
                                    createVNode(script$k, normalizeProps(guardReactiveProps(unref(pass))), null, 16 /* FULL_PROPS */)
                                ]),
                                createElementVNode("div", _hoisted_6, [
                                    createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                                ])
                            ]; }),
                            _: 1 /* STABLE */
                        }, 16 /* FULL_PROPS */))
                        : (openBlock(), createElementBlock("a", {
                            key: 3,
                            class: "notion-page-link",
                            target: props.pageLinkTarget,
                            href: props.mapPageUrl(unref(block).value.id)
                        }, [
                            createElementVNode("div", _hoisted_8, [
                                createVNode(script$k, normalizeProps(guardReactiveProps(unref(pass))), null, 16 /* FULL_PROPS */)
                            ]),
                            createElementVNode("div", _hoisted_9, [
                                createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ])
                        ], 8 /* PROPS */, _hoisted_7));
        };
    } }));

script$8.__file = "src/blocks/page.vue";

var _hoisted_1$6 = {
    key: 0,
    class: "notion-quote"
};
var __default__$5 = {
    name: "NotionQuote",
};
var script$7 = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$5), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), properties = _a.properties, title = _a.title, pass = _a.pass;
        return function (_ctx, _cache) {
            return (unref(properties))
                ? (openBlock(), createElementBlock("blockquote", _hoisted_1$6, [
                    createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ]))
                : createCommentVNode("v-if", true);
        };
    } }));

script$7.__file = "src/blocks/quote.vue";

var script$6 = {
    name: "NotionTable",
};

const _hoisted_1$5 = { class: "notion-simple-table-wrapper" };
const _hoisted_2$2 = { class: "notion-simple-table" };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("div", _hoisted_1$5, [
    createElementVNode("table", _hoisted_2$2, [
      createElementVNode("tbody", null, [
        renderSlot(_ctx.$slots, "default")
      ])
    ])
  ]))
}

script$6.render = render;
script$6.__file = "src/blocks/table.vue";

var _hoisted_1$4 = { class: "notion-simple-table-row" };
var _hoisted_2$1 = { class: "notion-simple-table-cell-text" };
var __default__$4 = {
    name: "NotionTableRow",
};
var script$5 = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$4), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), parent = _a.parent, properties = _a.properties, pass = _a.pass;
        var _b = parent.value.value.format, hasHeaderColumn = _b.table_block_column_header, hasHeaderRow = _b.table_block_row_header, columns = _b.table_block_column_order;
        var cell = function (columnId) {
            return properties.value[columnId];
        };
        var isHeader = function (columnIndex) {
            return (hasHeaderColumn && props.contentIndex == 0) || (hasHeaderRow && columnIndex == 0);
        };
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock("tr", _hoisted_1$4, [
                (openBlock(true), createElementBlock(Fragment, null, renderList(unref(columns), function (columnId, columnIndex) {
                    return (openBlock(), createElementBlock("td", {
                        key: columnIndex,
                        class: "notion-simple-table-data"
                    }, [
                        createElementVNode("div", {
                            class: normalizeClass({ 'notion-simple-table-header': isHeader(columnIndex) })
                        }, [
                            createElementVNode("div", _hoisted_2$1, [
                                createVNode(script$m, mergeProps({
                                    text: cell(columnId)
                                }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ])
                        ], 2 /* CLASS */)
                    ]));
                }), 128 /* KEYED_FRAGMENT */))
            ]));
        };
    } }));

script$5.__file = "src/blocks/table-row.vue";

var _hoisted_1$3 = {
    key: 1,
    class: "notion-blank"
};
var __default__$3 = {
    name: "NotionText",
};
var script$4 = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$3), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), properties = _a.properties, title = _a.title, pass = _a.pass, blockColorClass = _a.blockColorClass;
        return function (_ctx, _cache) {
            return (unref(properties))
                ? (openBlock(), createElementBlock("p", {
                    key: 0,
                    class: normalizeClass(['notion-text', unref(blockColorClass)()])
                }, [
                    createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ], 2 /* CLASS */))
                : (openBlock(), createElementBlock("div", _hoisted_1$3, " "));
        };
    } }));

script$4.__file = "src/blocks/text.vue";

var _hoisted_1$2 = ["value", "checked"];
var __default__$2 = {
    name: "NotionTodo",
};
var script$3 = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$2), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        // TODO: add notion styling
        // TODO: add strikethrough
        var _a = useNotionBlock(props), title = _a.title, properties = _a.properties, pass = _a.pass;
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock("div", null, [
                createElementVNode("input", {
                    type: "checkbox",
                    value: unref(title),
                    checked: unref(properties).checked,
                    disabled: "disabled"
                }, null, 8 /* PROPS */, _hoisted_1$2),
                createElementVNode("label", null, [
                    createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ])
            ]));
        };
    } }));

script$3.__file = "src/blocks/todo.vue";

var _hoisted_1$1 = { class: "notion-toggle" };
var __default__$1 = {
    name: "NotionToggle",
};
var script$2 = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__$1), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), title = _a.title, pass = _a.pass;
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock("details", _hoisted_1$1, [
                createElementVNode("summary", null, [
                    createVNode(script$m, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ]),
                createElementVNode("div", null, [
                    renderSlot(_ctx.$slots, "default")
                ])
            ]));
        };
    } }));

script$2.__file = "src/blocks/toggle.vue";

var _hoisted_1 = {
    key: 0,
    style: { "width": "100%" }
};
var _hoisted_2 = {
    key: 10,
    class: "notion-row"
};
var _hoisted_3 = {
    key: 16,
    class: "notion-hr"
};
var _hoisted_4 = { key: 17 };
var script$1 = /*#__PURE__*/ defineComponent({
    props: __assign({}, defineNotionProps),
    setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), pass = _a.pass, visible = _a.visible, type = _a.type, format = _a.format, isType = _a.isType;
        return function (_ctx, _cache) {
            return (openBlock(), createElementBlock(Fragment, null, [
                (unref(isType)('page'))
                    ? (openBlock(), createElementBlock("div", _hoisted_1, [
                        createVNode(script$8, normalizeProps(guardReactiveProps(unref(pass))), {
                            default: withCtx(function () { return [
                                renderSlot(_ctx.$slots, "default")
                            ]; }),
                            _: 3 /* FORWARDED */
                        }, 16 /* FULL_PROPS */)
                    ]))
                    : (unref(isType)(['header', 'sub_header', 'sub_sub_header']))
                        ? (openBlock(), createBlock(script$b, normalizeProps(mergeProps({ key: 1 }, unref(pass))), null, 16 /* FULL_PROPS */))
                        : (unref(isType)('bookmark'))
                            ? (openBlock(), createBlock(script$l, normalizeProps(mergeProps({ key: 2 }, unref(pass))), null, 16 /* FULL_PROPS */))
                            : (unref(isType)('callout'))
                                ? (openBlock(), createBlock(script$j, normalizeProps(mergeProps({ key: 3 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                : (unref(isType)('code'))
                                    ? (openBlock(), createBlock(script$h, normalizeProps(mergeProps({ key: 4 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                    : (unref(isType)('equation'))
                                        ? (openBlock(), createBlock(script$f, normalizeProps(mergeProps({ key: 5 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                        : (unref(isType)('text'))
                                            ? (openBlock(), createBlock(script$4, normalizeProps(mergeProps({ key: 6 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                            : (unref(isType)('quote'))
                                                ? (openBlock(), createBlock(script$7, normalizeProps(mergeProps({ key: 7 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                                : (unref(isType)('to_do'))
                                                    ? (openBlock(), createBlock(script$3, normalizeProps(mergeProps({ key: 8 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                                    : (unref(isType)('toggle'))
                                                        ? (openBlock(), createBlock(script$2, normalizeProps(mergeProps({ key: 9 }, unref(pass))), {
                                                            default: withCtx(function () { return [
                                                                renderSlot(_ctx.$slots, "default")
                                                            ]; }),
                                                            _: 3 /* FORWARDED */
                                                        }, 16 /* FULL_PROPS */))
                                                        : (unref(isType)('column_list'))
                                                            ? (openBlock(), createElementBlock("div", _hoisted_2, [
                                                                renderSlot(_ctx.$slots, "default")
                                                            ]))
                                                            : (unref(isType)('column'))
                                                                ? (openBlock(), createBlock(script$g, {
                                                                    key: 11,
                                                                    format: unref(format)
                                                                }, {
                                                                    default: withCtx(function () { return [
                                                                        renderSlot(_ctx.$slots, "default")
                                                                    ]; }),
                                                                    _: 3 /* FORWARDED */
                                                                }, 8 /* PROPS */, ["format"]))
                                                                : (unref(isType)(['bulleted_list', 'numbered_list']))
                                                                    ? (openBlock(), createBlock(script$9, normalizeProps(mergeProps({ key: 12 }, unref(pass))), {
                                                                        default: withCtx(function () { return [
                                                                            renderSlot(_ctx.$slots, "default")
                                                                        ]; }),
                                                                        _: 3 /* FORWARDED */
                                                                    }, 16 /* FULL_PROPS */))
                                                                    : (unref(isType)(['image', 'embed', 'figma', 'video', 'audio']))
                                                                        ? (openBlock(), createBlock(script$c, normalizeProps(mergeProps({ key: 13 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                                                        : (unref(isType)('table'))
                                                                            ? (openBlock(), createBlock(script$6, normalizeProps(mergeProps({ key: 14 }, unref(pass))), {
                                                                                default: withCtx(function () { return [
                                                                                    renderSlot(_ctx.$slots, "default")
                                                                                ]; }),
                                                                                _: 3 /* FORWARDED */
                                                                            }, 16 /* FULL_PROPS */))
                                                                            : (unref(isType)('table_row'))
                                                                                ? (openBlock(), createBlock(script$5, normalizeProps(mergeProps({ key: 15 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                                                                : (unref(isType)('divider'))
                                                                                    ? (openBlock(), createElementBlock("hr", _hoisted_3))
                                                                                    : (props.todo && unref(visible))
                                                                                        ? (openBlock(), createElementBlock("div", _hoisted_4, [
                                                                                            createTextVNode(" todo: " + toDisplayString(unref(type)) + " ", 1 /* TEXT */),
                                                                                            renderSlot(_ctx.$slots, "default")
                                                                                        ]))
                                                                                        : createCommentVNode("v-if", true),
                createCommentVNode(" todo: maybe add message on !production if block type unsupported "),
                createCommentVNode(" <div v-else-if=\"visible\"><slot /></div> ")
            ], 2112 /* STABLE_FRAGMENT, DEV_ROOT_FRAGMENT */));
        };
    }
});

script$1.__file = "src/components/block.vue";

var __default__ = {
    name: "NotionRenderer",
};
var script = /*#__PURE__*/ defineComponent(__assign(__assign({}, __default__), { props: __assign({}, defineNotionProps), setup: function (__props) {
        var props = __props;
        var _a = useNotionBlock(props), pass = _a.pass, block = _a.block;
        return function (_ctx, _cache) {
            var _component_NotionRenderer = resolveComponent("NotionRenderer", true);
            return (unref(block))
                ? (openBlock(), createBlock(script$1, normalizeProps(mergeProps({ key: 0 }, unref(pass))), {
                    default: withCtx(function () { return [
                        (openBlock(true), createElementBlock(Fragment, null, renderList(unref(block).value.content, function (contentId, contentIndex) {
                            return (openBlock(), createBlock(_component_NotionRenderer, mergeProps(unref(pass), {
                                key: contentId,
                                level: unref(pass).level + 1,
                                "content-id": contentId,
                                "content-index": contentIndex
                            }), null, 16 /* FULL_PROPS */, ["level", "content-id", "content-index"]));
                        }), 128 /* KEYED_FRAGMENT */))
                    ]; }),
                    _: 1 /* STABLE */
                }, 16 /* FULL_PROPS */))
                : createCommentVNode("v-if", true);
        };
    } }));

script.__file = "src/components/notion-renderer.vue";

var components = /*#__PURE__*/Object.freeze({
    __proto__: null,
    NotionRenderer: script
});

var getPageTable = function (pageId, apiUrl) {
    if (apiUrl === void 0) { apiUrl = "https://api.vue-notion.workers.dev/v1"; }
    return __awaiter(void 0, void 0, void 0, function () { return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, fetch("".concat(apiUrl, "/table/").concat(pageId)).then(function (res) { return res.json(); })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    }); });
};
var getPageBlocks = function (pageId, apiUrl) {
    if (apiUrl === void 0) { apiUrl = "https://api.vue-notion.workers.dev/v1"; }
    return __awaiter(void 0, void 0, void 0, function () { return __generator(this, function (_a) {
        switch (_a.label) {
            case 0: return [4 /*yield*/, fetch("".concat(apiUrl, "/page/").concat(pageId)).then(function (res) { return res.json(); })];
            case 1: return [2 /*return*/, _a.sent()];
        }
    }); });
};

var Role;
(function (Role) {
    Role["Reader"] = "reader";
})(Role || (Role = {}));

// Default export is library as a whole, registered via Vue.use()
var entry = {
    install: function (app) {
        Object.entries(components).forEach(function (_a) {
            var componentName = _a[0], component = _a[1];
            app.component(componentName, component);
        });
    },
};

export { script as NotionRenderer, Role, entry as default, getPageBlocks, getPageTable };
